aboutsummaryrefslogtreecommitdiff
path: root/gdb/symtab.c
diff options
context:
space:
mode:
Diffstat (limited to 'gdb/symtab.c')
-rw-r--r--gdb/symtab.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/gdb/symtab.c b/gdb/symtab.c
index 63d2a0e..0aa7321 100644
--- a/gdb/symtab.c
+++ b/gdb/symtab.c
@@ -4258,7 +4258,7 @@ find_epilogue_using_linetable (CORE_ADDR func_addr)
/* Move to the last linetable entry of the current function. */
if (it == &linetable->item[0])
{
/* Doing it-- would introduce undefined behaviour, avoid it by
explicitly handling this case. */
return {};
}
@@ -4292,7 +4292,7 @@ find_epilogue_using_linetable (CORE_ADDR func_addr)
if (it == &linetable->item[0])
{
/* No more entries in the current function.
- Doing it-- would introduce undefined behaviour, avoid it by
+ Doing it-- would introduce undefined behavior, avoid it by
explicitly handling this case. */
break;
}
@@ -4258,7 +4258,7 @@ find_epilogue_using_linetable (CORE_ADDR func_addr)
if (it == &linetable->item[0])
{
- /* Doing it-- would introduce undefined behaviour, avoid it by
+ /* Doing it-- would introduce undefined behavior, avoid it by
explicitly handling this case. */
return {};